@@ -1,4 +1,4 @@
-from typing import Dict, List
+from typing import Any, Dict, List, Tuple
 
 from typing_extensions import Annotated
 
@@ -11,13 +11,14 @@ from litestar.params import Body
 @post(path="/")
 async def handle_file_upload(
     data: Annotated[List[UploadFile], Body(media_type=RequestEncodingType.MULTI_PART)],
-) -> Dict[str, str]:
-    file_contents = {}
+) -> Dict[str, Tuple[str, str, Any]]:
+    result = {}
+
     for file in data:
         content = await file.read()
-        file_contents[file.filename] = content.decode()
+        result[file.filename] = (len(content), file.content_type, file.headers)
 
-    return file_contents
+    return result
 
 
 app = Litestar(route_handlers=[handle_file_upload])
