@@ -1,4 +1,4 @@
-from typing import Any, Dict
+from typing import Dict
 
 from pydantic import BaseModel, ConfigDict
 from typing_extensions import Annotated
@@ -18,7 +18,7 @@ class FormData(BaseModel):
 @post(path="/")
 async def handle_file_upload(
     data: Annotated[FormData, Body(media_type=RequestEncodingType.MULTI_PART)],
-) -> Dict[str, Any]:
+) -> Dict[str, str]:
     cv_content = await data.cv.read()
     diploma_content = await data.diploma.read()
 
