@@ -2,7 +2,19 @@ from litestar.app import Litestar
 from litestar.connection import Request, WebSocket
 from litestar.controller import Controller
 from litestar.enums import HttpMethod, MediaType
-from litestar.handlers import asgi, delete, get, head, patch, post, put, route, websocket, websocket_listener
+from litestar.handlers import (
+    asgi,
+    delete,
+    get,
+    head,
+    patch,
+    post,
+    put,
+    route,
+    websocket,
+    websocket_listener,
+    websocket_stream,
+)
 from litestar.response import Response
 from litestar.router import Router
 from litestar.utils.version import get_version
@@ -30,4 +42,5 @@ __all__ = (
     "route",
     "websocket",
     "websocket_listener",
+    "websocket_stream",
 )
