@@ -154,7 +154,9 @@ def _types_in_list(lst: list[Any]) -> list[OpenAPIType] | OpenAPIType:
             schema_types.append(schema_type)
         else:
             raise RuntimeError("Unexpected type for schema item")  # pragma: no cover
-    schema_types = list(set(schema_types))
+
+    # Ensure our schema types are sorted alphabetically for any downstream usage sensitive to order changes.
+    schema_types = sorted(set(schema_types))
     return schema_types[0] if len(schema_types) == 1 else schema_types
 
 
@@ -528,7 +530,7 @@ class SchemaCreator:
         Returns:
             A schema instance.
         """
-        kwarg_definition = cast(Union[ParameterKwarg, BodyKwarg], field.kwarg_definition)
+        kwarg_definition = cast("Union[ParameterKwarg, BodyKwarg]", field.kwarg_definition)
         if any(is_class_and_subclass(field.annotation, t) for t in (int, float, Decimal)):
             return create_numerical_constrained_field_schema(field.annotation, kwarg_definition)
         if any(is_class_and_subclass(field.annotation, t) for t in (str, bytes)):
@@ -547,7 +549,7 @@ class SchemaCreator:
             A schema instance.
         """
         schema = Schema(type=OpenAPIType.ARRAY)
-        kwarg_definition = cast(Union[ParameterKwarg, BodyKwarg], field_definition.kwarg_definition)
+        kwarg_definition = cast("Union[ParameterKwarg, BodyKwarg]", field_definition.kwarg_definition)
         if kwarg_definition.min_items:
             schema.min_items = kwarg_definition.min_items
         if kwarg_definition.max_items:
@@ -590,7 +592,9 @@ class SchemaCreator:
         schema.type = enum_type
         schema.enum = enum_values
         schema.title = get_name(field_definition.annotation)
-        schema.description = field_definition.annotation.__doc__
+        self.process_schema_result(field_definition, schema)
+        if schema.description is None:
+            schema.description = field_definition.annotation.__doc__
 
         return self.schema_registry.get_reference_for_field_definition(field_definition) or schema
 
