@@ -2,4 +2,4 @@ from .backends.base import ChannelsBackend
 from .plugin import ChannelsPlugin
 from .subscriber import Subscriber
 
-__all__ = ("ChannelsPlugin", "ChannelsBackend", "Subscriber")
+__all__ = ("ChannelsBackend", "ChannelsPlugin", "Subscriber")
