@@ -39,6 +39,11 @@ else:
 if TYPE_CHECKING:
     from types import ModuleType
 
+    try:
+        from rich_click import RichContext
+    except ImportError:
+        RichContext = Context  # type: ignore[assignment,misc]
+
     from litestar.openapi import OpenAPIConfig
     from litestar.routes import ASGIRoute, HTTPRoute, WebSocketRoute
     from litestar.types import AnyCallable
@@ -192,8 +197,6 @@ class LitestarExtensionGroup(LitestarGroup):
         super().__init__(name=name, commands=commands, **attrs)
 
         self._prepare_done = False
-        self._preparsed_app_dir: str | None = None
-        self._preparsed_app_path: Path | None = None
 
         for entry_point in entry_points(group="litestar.commands"):
             command = entry_point.load()
@@ -208,8 +211,8 @@ class LitestarExtensionGroup(LitestarGroup):
             env: LitestarEnv | None = ctx.obj
         else:
             try:
-                app_path = ctx.params.get("app_path", self._preparsed_app_path)
-                app_dir = ctx.params.get("app_dir", self._preparsed_app_dir)
+                app_path = ctx.params.get("app_path")
+                app_dir = ctx.params.get("app_dir")
                 env = ctx.obj = LitestarEnv.from_env(app_path, app_dir)
             except LitestarCLIException:
                 env = None
@@ -231,27 +234,15 @@ class LitestarExtensionGroup(LitestarGroup):
         self._prepare(ctx)
         return ctx
 
-    def parse_args(self, ctx: Context, args: list[str]) -> list[str]:
-        """Preparse launch arguments and save app_path & app_dir to slots.
-        This block is triggered in any case, but its results are only used if the --help command is invoked.
-        """
-        parser = self.make_parser(ctx)
-
-        original_ignore_unknown_option = ctx.ignore_unknown_options
-        ctx.ignore_unknown_options = True
-
-        opts, remaining_args, order = parser.parse_args(list(args))
-        self._preparsed_app_path = opts.get("app_path", None)
-        self._preparsed_app_dir = opts.get("app_dir", None)
-
-        ctx.ignore_unknown_options = original_ignore_unknown_option
-
-        return super().parse_args(ctx, args)
-
     def list_commands(self, ctx: Context) -> list[str]:
         self._prepare(ctx)
         return super().list_commands(ctx)
 
+    def format_help(self, ctx: Context, formatter: Any) -> None:
+        """Override format_help to ensure plugins are loaded before rendering help."""
+        self._prepare(ctx)
+        return super().format_help(ctx, formatter)  # type: ignore[arg-type]
+
 
 def _inject_args(func: Callable[P, T]) -> Callable[P, T]:
     """Inject the app instance into a ``Command``"""
