@@ -1,4 +1,4 @@
 from .emitter import BaseEventEmitterBackend, SimpleEventEmitter
 from .listener import EventListener, listener
 
-__all__ = ("EventListener", "SimpleEventEmitter", "BaseEventEmitterBackend", "listener")
+__all__ = ("BaseEventEmitterBackend", "EventListener", "SimpleEventEmitter", "listener")
