@@ -18,6 +18,8 @@ class WebsocketRouteHandler(BaseRouteHandler):
     Use this decorator to decorate websocket handler functions.
     """
 
+    __slots__ = ("websocket_class",)
+
     def __init__(
         self,
         path: str | list[str] | None = None,
@@ -47,9 +49,9 @@ class WebsocketRouteHandler(BaseRouteHandler):
                 :class:`ASGI Scope <.types.Scope>`.
             signature_namespace: A mapping of names to types for use in forward reference resolution during signature modelling.
             type_encoders: A mapping of types to callables that transform them into types supported for serialization.
-            **kwargs: Any additional kwarg - will be set in the opt dictionary.
             websocket_class: A custom subclass of :class:`WebSocket <.connection.WebSocket>` to be used as route handler's
                 default websocket class.
+            **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         self.websocket_class = websocket_class
 
@@ -83,17 +85,19 @@ class WebsocketRouteHandler(BaseRouteHandler):
         super()._validate_handler_function()
 
         if not self.parsed_fn_signature.return_type.is_subclass_of(NoneType):
-            raise ImproperlyConfiguredException("Websocket handler functions should return 'None'")
+            raise ImproperlyConfiguredException(f"{self}: WebSocket handlers must return 'None'")
 
         if "socket" not in self.parsed_fn_signature.parameters:
-            raise ImproperlyConfiguredException("Websocket handlers must set a 'socket' kwarg")
+            raise ImproperlyConfiguredException(f"{self}: WebSocket handlers must define a 'socket' parameter")
 
         for param in ("request", "body", "data"):
             if param in self.parsed_fn_signature.parameters:
-                raise ImproperlyConfiguredException(f"The {param} kwarg is not supported with websocket handlers")
+                raise ImproperlyConfiguredException(
+                    f"{self}: The {param} kwarg is not supported with websocket handlers"
+                )
 
         if not is_async_callable(self.fn):
-            raise ImproperlyConfiguredException("Functions decorated with 'websocket' must be async functions")
+            raise ImproperlyConfiguredException(f"{self}: WebSocket handler functions must be asynchronous")
 
 
 websocket = WebsocketRouteHandler
