@@ -2,4 +2,4 @@ from .config import OpenAPIConfig
 from .controller import OpenAPIController
 from .datastructures import ResponseSpec
 
-__all__ = ("OpenAPIController", "OpenAPIConfig", "ResponseSpec")
+__all__ = ("OpenAPIConfig", "OpenAPIController", "ResponseSpec")
