@@ -124,12 +124,17 @@ class KwargDefinition:
     Use as the key for the reference when creating a component for this type
     .. versionadded:: 2.12.0
     """
+    include_in_schema: bool = True
+    """
+    A boolean flag dictating whether this parameter should be included in the schema.
+    .. versionadded:: 2.17.0
+    """
 
     @property
     def is_constrained(self) -> bool:
         """Return True if any of the constraints are set."""
         return any(
-            attr if attr and attr is not Empty else False  # type: ignore[comparison-overlap]
+            attr is not None
             for attr in (
                 self.gt,
                 self.ge,
@@ -201,6 +206,7 @@ def Parameter(
     title: str | None = None,
     schema_extra: dict[str, Any] | None = None,
     schema_component_key: str | None = None,
+    include_in_schema: bool = True,
 ) -> Any:
     """Create an extended parameter kwarg definition.
 
@@ -247,6 +253,7 @@ def Parameter(
             .. versionadded:: 2.8.0
         schema_component_key: Use this as the key for the reference when creating a component for this type
             .. versionadded:: 2.12.0
+        include_in_schema: A boolean flag dictating whether this parameter should be included in the schema.
     """
     return ParameterKwarg(
         annotation=annotation,
@@ -273,6 +280,7 @@ def Parameter(
         pattern=pattern,
         schema_extra=schema_extra,
         schema_component_key=schema_component_key,
+        include_in_schema=include_in_schema,
     )
 
 
