@@ -39,8 +39,7 @@ def _create_default_route_handler(
 ) -> HTTPRouteHandler:
     handler_decorator = _decorator_http_method_map[http_method]
 
-    def _default_route_handler() -> None:
-        ...
+    def _default_route_handler() -> None: ...
 
     handler = handler_decorator("/", sync_to_thread=False, **(handler_kwargs or {}))(_default_route_handler)
     handler.owner = app
@@ -56,12 +55,12 @@ class RequestFactory:
 
     __slots__ = (
         "app",
-        "server",
+        "handler_kwargs",
         "port",
         "root_path",
         "scheme",
-        "handler_kwargs",
         "serializer",
+        "server",
     )
 
     def __init__(
@@ -76,7 +75,7 @@ class RequestFactory:
         """Initialize ``RequestFactory``
 
         Args:
-             app: An instance of :class:`Litestar <litestar.app.Litestar>` to set as ``request.scope["app"]``.
+             app: An instance of :class:`Litestar <litestar.app.Litestar>` to set as ``request.scope["litestar_app"]``.
              server: The server's domain.
              port: The server's port.
              root_path: Root path for the server.
@@ -176,6 +175,7 @@ class RequestFactory:
             path=path,
             headers=[],
             app=self.app,
+            litestar_app=self.app,
             session=session,
             user=user,
             auth=auth,
@@ -189,6 +189,7 @@ class RequestFactory:
             route_handler=route_handler
             or _create_default_route_handler(http_method, self.handler_kwargs, app=self.app),
             extensions={},
+            path_template="",
         )
 
     @classmethod
@@ -301,7 +302,9 @@ class RequestFactory:
             headers.update(encoding_headers)
             for chunk in stream:
                 body += chunk
-        ScopeState.from_scope(scope).body = body
+        scope_state = ScopeState.from_scope(scope)
+        scope_state.body = body
+        scope_state.exception_handlers = scope["route_handler"].resolve_exception_handlers()
         self._create_cookie_header(headers, cookies)
         scope["headers"] = self._build_headers(headers)
         return Request(scope=scope)
