@@ -9,8 +9,9 @@ from litestar.utils.empty import value_or_default
 if TYPE_CHECKING:
     from typing_extensions import Self
 
-    from litestar.datastructures import URL, Accept, Headers
+    from litestar.datastructures import URL, Accept, Headers, UploadFile
     from litestar.types.asgi_types import Scope
+    from litestar.types.composite_types import ExceptionHandlersMap
 
 CONNECTION_STATE_KEY: Final = "_ls_connection_state"
 
@@ -25,6 +26,7 @@ class ScopeState:
     """
 
     __slots__ = (
+        "_compat_ns",
         "accept",
         "base_url",
         "body",
@@ -33,6 +35,8 @@ class ScopeState:
         "csrf_token",
         "dependency_cache",
         "do_cache",
+        "exception_handlers",
+        "flash_messages",
         "form",
         "headers",
         "is_cached",
@@ -41,9 +45,9 @@ class ScopeState:
         "msgpack",
         "parsed_query",
         "response_compressed",
+        "response_started",
         "session_id",
         "url",
-        "_compat_ns",
     )
 
     def __init__(self) -> None:
@@ -55,7 +59,9 @@ class ScopeState:
         self.csrf_token = Empty
         self.dependency_cache = Empty
         self.do_cache = Empty
+        self.exception_handlers = Empty
         self.form = Empty
+        self.flash_messages = []
         self.headers = Empty
         self.is_cached = Empty
         self.json = Empty
@@ -63,6 +69,7 @@ class ScopeState:
         self.msgpack = Empty
         self.parsed_query = Empty
         self.response_compressed = Empty
+        self.response_started = False
         self.session_id = Empty
         self.url = Empty
         self._compat_ns: dict[str, Any] = {}
@@ -75,7 +82,9 @@ class ScopeState:
     csrf_token: str | EmptyType
     dependency_cache: dict[str, Any] | EmptyType
     do_cache: bool | EmptyType
-    form: dict[str, str | list[str]] | EmptyType
+    exception_handlers: ExceptionHandlersMap | EmptyType
+    form: dict[str, str | list[str] | UploadFile] | EmptyType
+    flash_messages: list[dict[str, str]]
     headers: Headers | EmptyType
     is_cached: bool | EmptyType
     json: Any | EmptyType
@@ -83,6 +92,7 @@ class ScopeState:
     msgpack: Any | EmptyType
     parsed_query: tuple[tuple[str, str], ...] | EmptyType
     response_compressed: bool | EmptyType
+    response_started: bool
     session_id: str | None | EmptyType
     url: URL | EmptyType
     _compat_ns: dict[str, Any]
