@@ -10,6 +10,7 @@ from litestar.testing import create_test_client
 
 if TYPE_CHECKING:
     from litestar.connection import Request
+    from litestar.datastructures.state import State
 
 
 def router_first_dependency() -> bool:
@@ -21,12 +22,12 @@ async def router_second_dependency() -> bool:
     return False
 
 
-def controller_first_dependency(headers: Dict[str, Any]) -> dict:
+def controller_first_dependency(headers: Dict[str, Any]) -> Dict[Any, Any]:
     assert headers
     return {}
 
 
-async def controller_second_dependency(request: "Request") -> dict:
+async def controller_second_dependency(request: "Request[Any, Any, State]") -> Dict[Any, Any]:
     assert request
     await sleep(0)
     return {}
@@ -60,7 +61,7 @@ def first_controller() -> Type[Controller]:
                 "first": Provide(local_method_first_dependency, sync_to_thread=False),
             },
         )
-        def test_method(self, first: int, second: dict, third: bool) -> None:
+        def test_method(self, first: int, second: Dict[Any, Any], third: bool) -> None:
             assert isinstance(first, int)
             assert isinstance(second, dict)
             assert not third
@@ -109,7 +110,7 @@ def test_dependency_isolation(first_controller: Type[Controller]) -> None:
         path = "/second"
 
         @get()
-        def test_method(self, first: dict) -> None:
+        def test_method(self, first: Dict[Any, Any]) -> None:
             pass
 
     with create_test_client([first_controller, SecondController]) as client:
