@@ -5,6 +5,7 @@ import pytest
 
 from litestar import Controller, websocket
 from litestar.connection import WebSocket
+from litestar.datastructures import State
 from litestar.di import Provide
 from litestar.exceptions import WebSocketDisconnect
 from litestar.testing import create_test_client
@@ -19,12 +20,12 @@ async def router_second_dependency() -> bool:
     return False
 
 
-def controller_first_dependency(headers: Dict[str, Any]) -> dict:
+def controller_first_dependency(headers: Dict[str, Any]) -> Dict[Any, Any]:
     assert headers
     return {}
 
 
-async def controller_second_dependency(socket: WebSocket) -> dict:
+async def controller_second_dependency(socket: WebSocket[Any, Any, Any]) -> Dict[Any, Any]:
     assert socket
     await sleep(0)
     return {}
@@ -56,7 +57,9 @@ class FirstController(Controller):
             "first": Provide(local_method_first_dependency, sync_to_thread=False),
         },
     )
-    async def test_method(self, socket: WebSocket, first: int, second: dict, third: bool) -> None:
+    async def test_method(
+        self, socket: WebSocket[Any, Any, Any], first: int, second: Dict[Any, Any], third: bool
+    ) -> None:
         await socket.accept()
         msg = await socket.receive_json()
         assert msg
@@ -87,7 +90,7 @@ def test_function_dependency_injection() -> None:
             "third": Provide(local_method_second_dependency, sync_to_thread=False),
         },
     )
-    async def test_function(socket: WebSocket, first: int, second: bool, third: str) -> None:
+    async def test_function(socket: WebSocket[Any, Any, State], first: int, second: bool, third: str) -> None:
         await socket.accept()
         assert socket
         msg = await socket.receive_json()
@@ -113,7 +116,7 @@ def test_dependency_isolation() -> None:
         path = "/second"
 
         @websocket()
-        async def test_method(self, socket: WebSocket, first: dict) -> None:
+        async def test_method(self, socket: WebSocket[Any, Any, Any], _: Dict[Any, Any]) -> None:
             await socket.accept()
 
     client = create_test_client([FirstController, SecondController])
