@@ -6,7 +6,7 @@ import logging
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
 from dataclasses import fields
-from typing import TYPE_CHECKING, Callable, List, Tuple
+from typing import TYPE_CHECKING, Any, Callable, List, Tuple
 from unittest.mock import MagicMock, Mock, PropertyMock
 
 import pytest
@@ -14,7 +14,8 @@ from click import Group
 from pytest import MonkeyPatch
 
 from litestar import Litestar, MediaType, Request, Response, get
-from litestar.config.app import AppConfig
+from litestar._asgi.asgi_router import ASGIRouter
+from litestar.config.app import AppConfig, ExperimentalFeatures
 from litestar.config.response_cache import ResponseCacheConfig
 from litestar.contrib.sqlalchemy.plugins import SQLAlchemySerializationPlugin
 from litestar.datastructures import MutableScopeHeaders, State
@@ -172,6 +173,7 @@ def test_app_config_object_used(app_config_object: AppConfig, monkeypatch: pytes
     monkeypatch.setattr(Litestar, "register", MagicMock())
     monkeypatch.setattr(Litestar, "_create_asgi_handler", MagicMock())
     monkeypatch.setattr(Router, "__init__", MagicMock())
+    monkeypatch.setattr(ASGIRouter, "__init__", MagicMock(return_value=None))
 
     # instantiates the app with an `on_app_config` that returns our patched `AppConfig` object.
     Litestar(on_app_init=[MagicMock(return_value=app_config_object)])
@@ -241,7 +243,7 @@ def test_before_send() -> None:
     async def before_send_hook_handler(message: Message, scope: Scope) -> None:
         if message["type"] == "http.response.start":
             headers = MutableScopeHeaders(message)
-            headers.add("My Header", scope["app"].state.message)
+            headers.add("My Header", Litestar.from_scope(scope).state.message)
 
     def on_startup(app: Litestar) -> None:
         app.state.message = "value injected during send"
@@ -254,10 +256,9 @@ def test_before_send() -> None:
 
 def test_using_custom_http_exception_handler() -> None:
     @get("/{param:int}")
-    def my_route_handler(param: int) -> None:
-        ...
+    def my_route_handler(param: int) -> None: ...
 
-    def my_custom_handler(_: Request, __: Exception) -> Response:
+    def my_custom_handler(_: Request[Any, Any, State], __: Exception) -> Response[str]:
         return Response(content="custom message", media_type=MediaType.TEXT, status_code=HTTP_400_BAD_REQUEST)
 
     with create_test_client(my_route_handler, exception_handlers={NotFoundException: my_custom_handler}) as client:
@@ -446,3 +447,38 @@ def test_lifespan_context_and_shutdown_hook_execution_order() -> None:
     assert events[1] == "ctx_1"
     assert events[2] == "hook_a"
     assert events[3] == "hook_b"
+
+
+def test_use_dto_codegen_feature_flag_warns() -> None:
+    with pytest.warns(LitestarWarning, match="Use of redundant experimental feature flag DTO_CODEGEN"):
+        Litestar(experimental_features=[ExperimentalFeatures.DTO_CODEGEN])
+
+
+def test_use_future_feature_flag_warns() -> None:
+    app = Litestar(experimental_features=[ExperimentalFeatures.FUTURE])
+    assert app.experimental_features == frozenset([ExperimentalFeatures.FUTURE])
+
+
+def test_using_custom_path_parameter() -> None:
+    @get()
+    def my_route_handler() -> None: ...
+
+    with create_test_client(my_route_handler, path="/abc") as client:
+        response = client.get("/abc")
+        assert response.status_code == HTTP_200_OK
+
+
+def test_from_scope() -> None:
+    mock = MagicMock()
+
+    @get()
+    def handler(scope: Scope) -> None:
+        mock(Litestar.from_scope(scope))
+        return
+
+    app = Litestar(route_handlers=[handler])
+
+    with TestClient(app) as client:
+        client.get("/")
+
+    mock.assert_called_once_with(app)
