@@ -2,6 +2,7 @@
 Some tests in this file were adapted from: https://github.com/encode/starlette/blob/master/tests/test_websockets.py And
 were meant to ensure our compatibility with their API.
 """
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, AsyncGenerator, Literal
@@ -11,6 +12,7 @@ import anyio
 import pytest
 
 from litestar.connection import WebSocket
+from litestar.datastructures import State
 from litestar.datastructures.headers import Headers
 from litestar.exceptions import WebSocketDisconnect, WebSocketException
 from litestar.handlers.websocket_handlers import websocket
@@ -26,7 +28,7 @@ if TYPE_CHECKING:
 @pytest.mark.parametrize("mode", ["text", "binary"])
 def test_websocket_send_receive_json(mode: Literal["text", "binary"]) -> None:
     @websocket(path="/")
-    async def websocket_handler(socket: WebSocket) -> None:
+    async def websocket_handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         recv = await socket.receive_json(mode=mode)
         await socket.send_json({"message": recv}, mode=mode)
@@ -42,7 +44,7 @@ def test_route_handler_property() -> None:
     value: Any = {}
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         value["handler"] = socket.route_handler
         await socket.close()
@@ -56,7 +58,7 @@ def test_route_handler_property() -> None:
 )
 async def test_accept_set_headers(headers: Any) -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept(headers=headers)
         await socket.send_text("abc")
         await socket.close()
@@ -68,7 +70,7 @@ async def test_accept_set_headers(headers: Any) -> None:
 async def test_custom_request_class() -> None:
     value: Any = {}
 
-    class MyWebSocket(WebSocket[Any, Any, Any]):
+    class MyWebSocket(WebSocket[Any, Any, State]):
         def __init__(self, *args: Any, **kwargs: Any) -> None:
             super().__init__(*args, **kwargs)
             self.scope["called"] = True  # type: ignore[typeddict-unknown-key]
@@ -85,18 +87,29 @@ async def test_custom_request_class() -> None:
 
 def test_websocket_url() -> None:
     @websocket("/123")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         await socket.send_json({"url": str(socket.url)})
         await socket.close()
 
     with create_test_client(handler).websocket_connect("/123?a=abc") as ws:
-        assert ws.receive_json() == {"url": "ws://testserver/123?a=abc"}
+        assert ws.receive_json() == {"url": "ws://testserver.local/123?a=abc"}
+
+
+def test_websocket_url_respects_custom_base_url() -> None:
+    @websocket("/123")
+    async def handler(socket: WebSocket) -> None:
+        await socket.accept()
+        await socket.send_json({"url": str(socket.url)})
+        await socket.close()
+
+    with create_test_client(handler, base_url="http://example.org").websocket_connect("/123?a=abc") as ws:
+        assert ws.receive_json() == {"url": "ws://example.org/123?a=abc"}
 
 
 def test_websocket_binary_json() -> None:
     @websocket("/123")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         message = await socket.receive_json(mode="binary")
         await socket.send_json(message, mode="binary")
@@ -109,7 +122,7 @@ def test_websocket_binary_json() -> None:
 
 def test_websocket_query_params() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         query_params = dict(socket.query_params)
         await socket.accept()
         await socket.send_json({"params": query_params})
@@ -121,7 +134,7 @@ def test_websocket_query_params() -> None:
 
 def test_websocket_headers() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         headers = dict(socket.headers)
         await socket.accept()
         await socket.send_json({"headers": headers})
@@ -132,7 +145,7 @@ def test_websocket_headers() -> None:
             "accept": "*/*",
             "accept-encoding": "gzip, deflate, br",
             "connection": "upgrade",
-            "host": "testserver",
+            "host": "testserver.local",
             "user-agent": "testclient",
             "sec-websocket-key": "testserver==",
             "sec-websocket-version": "13",
@@ -142,7 +155,7 @@ def test_websocket_headers() -> None:
 
 def test_websocket_port() -> None:
     @websocket("/123")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         await socket.send_json({"port": socket.url.port})
         await socket.close()
@@ -153,7 +166,7 @@ def test_websocket_port() -> None:
 
 def test_websocket_send_and_receive_text() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         data = await socket.receive_text()
         await socket.send_text(f"Message was: {data}")
@@ -166,7 +179,7 @@ def test_websocket_send_and_receive_text() -> None:
 
 def test_websocket_send_and_receive_bytes() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         data = await socket.receive_bytes()
         await socket.send_bytes(b"Message was: " + data)
@@ -179,7 +192,7 @@ def test_websocket_send_and_receive_bytes() -> None:
 
 def test_websocket_send_and_receive_json() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         data = await socket.receive_json()
         await socket.send_json({"message": data})
@@ -194,7 +207,7 @@ def test_send_msgpack() -> None:
     test_data = {"message": "hello, world"}
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         await socket.send_msgpack(test_data)
         await socket.close()
@@ -209,7 +222,7 @@ def test_receive_msgpack() -> None:
     callback = MagicMock()
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         data = await socket.receive_msgpack()
         callback(data)
@@ -237,7 +250,7 @@ def test_iter_data(mode: WebSocketMode, data: list[str | bytes]) -> None:
     values = []
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         values.extend(await consume_gen(socket.iter_data(mode=mode), 2))
         await socket.close()
@@ -255,7 +268,7 @@ def test_iter_json(mode: WebSocketMode) -> None:
     values = []
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         values.extend(await consume_gen(socket.iter_json(mode=mode), 2))
         await socket.close()
@@ -272,7 +285,7 @@ def test_iter_msgpack() -> None:
     values = []
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         values.extend(await consume_gen(socket.iter_msgpack(), 2))
         await socket.close()
@@ -287,18 +300,18 @@ def test_iter_msgpack() -> None:
 def test_websocket_concurrency_pattern() -> None:
     stream_send, stream_receive = anyio.create_memory_object_stream()  # type: ignore[var-annotated]
 
-    async def reader(socket: WebSocket[Any, Any, Any]) -> None:
+    async def reader(socket: WebSocket[Any, Any, State]) -> None:
         async with stream_send:
             json_data = await socket.receive_json()
             await stream_send.send(json_data)
 
-    async def writer(socket: WebSocket[Any, Any, Any]) -> None:
+    async def writer(socket: WebSocket[Any, Any, State]) -> None:
         async with stream_receive:
             async for message in stream_receive:
                 await socket.send_json(message)
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         async with anyio.create_task_group() as task_group:
             task_group.start_soon(reader, socket)
@@ -315,7 +328,7 @@ def test_client_close() -> None:
     close_code = None
 
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         nonlocal close_code
         await socket.accept()
         try:
@@ -330,7 +343,7 @@ def test_client_close() -> None:
 
 def test_application_close() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         await socket.close(WS_1001_GOING_AWAY)
 
@@ -341,7 +354,7 @@ def test_application_close() -> None:
 
 def test_rejected_connection() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.close(WS_1001_GOING_AWAY)
 
     with pytest.raises(WebSocketDisconnect) as exc, create_test_client(handler).websocket_connect("/"):
@@ -351,7 +364,7 @@ def test_rejected_connection() -> None:
 
 def test_subprotocol() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         assert socket.scope["subprotocols"] == ["soap", "wamp"]
         await socket.accept(subprotocols="wamp")
         await socket.close()
@@ -362,7 +375,7 @@ def test_subprotocol() -> None:
 
 def test_additional_headers() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept(headers=[(b"additional", b"header")])
         await socket.close()
 
@@ -372,7 +385,7 @@ def test_additional_headers() -> None:
 
 def test_no_additional_headers() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         await socket.close()
 
@@ -390,7 +403,7 @@ def test_websocket_exception() -> None:
 
 def test_duplicate_disconnect() -> None:
     async def app(scope: Scope, receive: Receive, send: Send) -> None:
-        socket = WebSocket[Any, Any, Any](scope, receive=receive, send=send)
+        socket = WebSocket[Any, Any, State](scope, receive=receive, send=send)
         await socket.accept()
         message = await socket.receive()
         assert message["type"] == "websocket.disconnect"
@@ -402,7 +415,7 @@ def test_duplicate_disconnect() -> None:
 
 def test_websocket_close_reason() -> None:
     @websocket("/")
-    async def handler(socket: WebSocket) -> None:
+    async def handler(socket: WebSocket[Any, Any, State]) -> None:
         await socket.accept()
         await socket.close(code=WS_1001_GOING_AWAY, reason="Going Away")
 
@@ -414,7 +427,7 @@ def test_websocket_close_reason() -> None:
 
 def test_receive_text_before_accept() -> None:
     async def app(scope: Scope, receive: Receive, send: Send) -> None:
-        socket = WebSocket[Any, Any, Any](scope, receive=receive, send=send)
+        socket = WebSocket[Any, Any, State](scope, receive=receive, send=send)
         await socket.receive_text()
 
     with pytest.raises(WebSocketException), TestClient(app).websocket_connect("/"):
@@ -423,7 +436,7 @@ def test_receive_text_before_accept() -> None:
 
 def test_receive_bytes_before_accept() -> None:
     async def app(scope: Scope, receive: Receive, send: Send) -> None:
-        socket = WebSocket[Any, Any, Any](scope, receive=receive, send=send)
+        socket = WebSocket[Any, Any, State](scope, receive=receive, send=send)
         await socket.receive_bytes()
 
     with pytest.raises(WebSocketException), TestClient(app).websocket_connect("/"):
@@ -432,7 +445,7 @@ def test_receive_bytes_before_accept() -> None:
 
 def test_receive_json_before_accept() -> None:
     async def app(scope: Scope, receive: Receive, send: Send) -> None:
-        socket = WebSocket[Any, Any, Any](scope, receive=receive, send=send)
+        socket = WebSocket[Any, Any, State](scope, receive=receive, send=send)
         await socket.receive_json()
 
     with pytest.raises(WebSocketException), TestClient(app).websocket_connect("/"):
