@@ -6,7 +6,7 @@ from dataclasses import asdict, dataclass
 from os import path
 from os.path import dirname, join, realpath
 from pathlib import Path
-from typing import Any, DefaultDict, Dict, List, Optional
+from typing import Any, DefaultDict, Dict, List, Optional, Type, Union
 
 import msgspec
 import pytest
@@ -406,7 +406,7 @@ def test_upload_multiple_files(file_count: int, optional: bool) -> None:
         annotation = Optional[annotation]  # type: ignore[misc, assignment]
 
     @post("/", signature_namespace={"annotation": annotation})
-    async def handler(data: annotation = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:  # pyright: ignore[reportGeneralTypeIssues]
+    async def handler(data: annotation = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:  # pyright: ignore
         assert len(data) == file_count
 
         for file in data:
@@ -432,7 +432,7 @@ class OptionalFiles:
 
 @pytest.mark.parametrize("file_model", (Files, OptionalFiles))
 @pytest.mark.parametrize("file_count", (1, 2))
-def test_upload_multiple_files_in_model(file_count: int, file_model: type[Files | OptionalFiles]) -> None:
+def test_upload_multiple_files_in_model(file_count: int, file_model: Type[Union[Files, OptionalFiles]]) -> None:
     @post("/", signature_namespace={"file_model": file_model})
     async def handler(data: file_model = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:  # type: ignore[valid-type]
         assert len(data.file_list) == file_count  # type: ignore[attr-defined]
@@ -505,14 +505,28 @@ class ProductForm:
     optional_with_default: Optional[int] = None
 
 
-def test_multipart_handling_of_none_values() -> None:
+def test_multipart_handling_of_optional_values() -> None:
+    # https://github.com/litestar-org/litestar/issues/4204
+    """Test that multipart forms handle optional fields correctly.
+
+    This test verifies that optional fields work properly with valid values,
+    and demonstrates the correct behavior after fixing issue #4204.
+    """
+
     @post("/", signature_types=[ProductForm])
     def handler(
         data: Annotated[ProductForm, Body(media_type=RequestEncodingType.MULTI_PART)],
-    ) -> None:
-        assert data
+    ) -> Dict[str, Any]:
+        return {
+            "name": data.name,
+            "int_field": data.int_field,
+            "options": data.options,
+            "optional_without_default": data.optional_without_default,
+            "optional_with_default": data.optional_with_default,
+        }
 
     with create_test_client(route_handlers=[handler]) as client:
+        # Test with valid values for all fields
         response = client.post(
             "/",
             content=(
@@ -530,15 +544,23 @@ def test_multipart_handling_of_none_values() -> None:
                 b"[1,2,3,4]\r\n"
                 b"--1f35df74046888ceaa62d8a534a076dd\r\n"
                 b'Content-Disposition: form-data; name="optional_without_default"\r\n'
-                b"Content-Type: application/octet-stream\r\n\r\n\r\n"
+                b"Content-Type: application/octet-stream\r\n\r\n"
+                b"3.14\r\n"
                 b"--1f35df74046888ceaa62d8a534a076dd\r\n"
                 b'Content-Disposition: form-data; name="optional_with_default"\r\n'
-                b"Content-Type: application/octet-stream\r\n\r\n\r\n"
+                b"Content-Type: application/octet-stream\r\n\r\n"
+                b"42\r\n"
                 b"--1f35df74046888ceaa62d8a534a076dd--\r\n"
             ),
             headers={"Content-Type": "multipart/form-data; boundary=1f35df74046888ceaa62d8a534a076dd"},
         )
         assert response.status_code == HTTP_201_CREATED
+        result = response.json()
+        assert result["name"] == "moishe zuchmir"
+        assert result["int_field"] == 1
+        assert result["options"] == "[1,2,3,4]"
+        assert result["optional_without_default"] == 3.14
+        assert result["optional_with_default"] == 42
 
 
 class AddProductFormMsgspec(msgspec.Struct):
@@ -598,3 +620,36 @@ def test_invalid_multipart_raises_client_error() -> None:
             headers={"Content-Type": "multipart/form-data; charset=utf-8; boundary=20b303e711c4ab8c443184ac833ab00f"},
         )
         assert response.status_code == HTTP_400_BAD_REQUEST
+
+
+# https://github.com/litestar-org/litestar/issues/4204
+def test_empty_strings_preserved_in_multipart_forms() -> None:
+    """Test that empty strings are preserved in multipart forms."""
+
+    @post("/test-form")
+    async def form_handler(request: Request) -> None:
+        data = await request.form()
+        assert data.get("value") == ""
+
+    with create_test_client([form_handler]) as client:
+        client.post("/test-form", data={"value": ""}, files={"dummy": ""})
+
+
+def test_empty_strings_consistency_between_encodings() -> None:
+    """Test that empty strings behave consistently between URL-encoded and multipart forms."""
+
+    @post("/consistency-test")
+    async def consistency_handler(request: Request) -> str:
+        data = await request.form()
+        assert isinstance(data["value"], str)
+        return data["value"]
+
+    with create_test_client([consistency_handler]) as client:
+        # Test URL-encoded form
+        response_url = client.post("/consistency-test", data={"value": ""})
+
+        # Test multipart form
+        response_multipart = client.post("/consistency-test", data={"value": ""}, files={"dummy": ""})
+
+        # Results should be identical
+        assert response_url.text == response_multipart.text
