@@ -196,6 +196,8 @@ async def test_compression_streaming_response_emitted_messages(
     # second body message with more_body=True will be empty if zlib buffers output and is not flushed
     await wrapped_send(HTTPResponseBodyEvent(type="http.response.body", body=b"abc", more_body=True))
     assert mock.mock_calls[-1].args[0]["body"]
+    # send a more_body=False so resources close properly
+    await wrapped_send(HTTPResponseBodyEvent(type="http.response.body", body=b"", more_body=False))
 
 
 @pytest.mark.parametrize(
@@ -238,8 +240,7 @@ def test_compression_with_custom_backend(handler: HTTPRouteHandler) -> None:
         def write(self, body: bytes) -> None:
             self.buffer.write(zlib.compress(body, level=self.config.backend_config["level"]))
 
-        def close(self) -> None:
-            ...
+        def close(self) -> None: ...
 
     zlib_config = {"level": 9}
     config = CompressionConfig(backend="deflate", compression_facade=ZlibCompression, backend_config=zlib_config)
