@@ -3,8 +3,9 @@ from typing import Any, Callable, Dict, List, Type
 from unittest.mock import ANY, MagicMock
 
 import pytest
+from typing_extensions import Annotated
 
-from litestar import Controller, Litestar, post
+from litestar import Controller, Litestar, get, post
 from litestar._openapi.datastructures import OpenAPIContext
 from litestar._openapi.request_body import create_request_body
 from litestar.datastructures.upload_file import UploadFile
@@ -56,6 +57,31 @@ def test_create_request_body(person_controller: Type[Controller], create_request
                 assert request_body
 
 
+def test_request_body_schema_extra() -> None:
+    @dataclass
+    class RequestBody:
+        foo: str
+
+    @get()
+    async def handler(
+        body1: Annotated[
+            RequestBody,
+            Body(
+                title="Default title",
+                schema_extra={
+                    "title": "Overridden title",
+                },
+            ),
+        ],
+    ) -> Any:
+        return body1
+
+    app = Litestar([handler])
+    schema = app.openapi_schema.to_schema()
+    resp = next(iter(schema["components"]["schemas"].values()))
+    assert resp["title"] == "Overridden title"
+
+
 def test_upload_single_file_schema_generation() -> None:
     @post(path="/file-upload")
     async def handle_file_upload(
