@@ -69,17 +69,17 @@ def test_openapi_to_typescript_converter(person_controller: Type[Controller], pe
 
 	export namespace Http201 {
 	export type ResponseBody = {
-	complex: {
+	complex?: {
 	
 };
-	first_name: string;
-	id: string;
-	last_name: string;
-	optional: null | string;
-	pets: null | {
-	age: number;
-	name: string;
-	species: "Cat" | "Dog" | "Monkey" | "Pig";
+	first_name?: string;
+	id?: string;
+	last_name?: string;
+	optional?: null | string;
+	pets?: null | {
+	age?: number;
+	name?: string;
+	species?: "Cat" | "Dog" | "Monkey" | "Pig";
 }[];
 }[];
 };
@@ -97,17 +97,17 @@ def test_openapi_to_typescript_converter(person_controller: Type[Controller], pe
 };
 
 	export type RequestBody = {
-	complex: {
+	complex?: {
 	
 };
-	first_name: string;
-	id: string;
-	last_name: string;
-	optional: null | string;
-	pets: null | {
-	age: number;
-	name: string;
-	species: "Cat" | "Dog" | "Monkey" | "Pig";
+	first_name?: string;
+	id?: string;
+	last_name?: string;
+	optional?: null | string;
+	pets?: null | {
+	age?: number;
+	name?: string;
+	species?: "Cat" | "Dog" | "Monkey" | "Pig";
 }[];
 }[];
 };
@@ -119,17 +119,17 @@ def test_openapi_to_typescript_converter(person_controller: Type[Controller], pe
 
 	export namespace Http200 {
 	export type ResponseBody = {
-	complex: {
+	complex?: {
 	
 };
-	first_name: string;
-	id: string;
-	last_name: string;
-	optional: null | string;
-	pets: null | {
-	age: number;
-	name: string;
-	species: "Cat" | "Dog" | "Monkey" | "Pig";
+	first_name?: string;
+	id?: string;
+	last_name?: string;
+	optional?: null | string;
+	pets?: null | {
+	age?: number;
+	name?: string;
+	species?: "Cat" | "Dog" | "Monkey" | "Pig";
 }[];
 }[];
 };
@@ -147,17 +147,17 @@ def test_openapi_to_typescript_converter(person_controller: Type[Controller], pe
 };
 
 	export type RequestBody = {
-	complex: {
+	complex?: {
 	
 };
-	first_name: string;
-	id: string;
-	last_name: string;
-	optional: null | string;
-	pets: null | {
-	age: number;
-	name: string;
-	species: "Cat" | "Dog" | "Monkey" | "Pig";
+	first_name?: string;
+	id?: string;
+	last_name?: string;
+	optional?: null | string;
+	pets?: null | {
+	age?: number;
+	name?: string;
+	species?: "Cat" | "Dog" | "Monkey" | "Pig";
 }[];
 }[];
 };
@@ -396,17 +396,17 @@ def test_openapi_to_typescript_converter(person_controller: Type[Controller], pe
 	export namespace ServiceIdPersonPersonIdPartialUpdatePerson {
 	export namespace Http200 {
 	export type ResponseBody = {
-	complex: {
+	complex?: {
 	
 };
-	first_name: string;
-	id: string;
-	last_name: string;
-	optional: null | string;
-	pets: null | {
-	age: number;
-	name: string;
-	species: "Cat" | "Dog" | "Monkey" | "Pig";
+	first_name?: string;
+	id?: string;
+	last_name?: string;
+	optional?: null | string;
+	pets?: null | {
+	age?: number;
+	name?: string;
+	species?: "Cat" | "Dog" | "Monkey" | "Pig";
 }[];
 };
 };
@@ -425,17 +425,17 @@ def test_openapi_to_typescript_converter(person_controller: Type[Controller], pe
 };
 
 	export type RequestBody = {
-	complex: {
+	complex?: {
 	
 };
-	first_name: string;
-	id: string;
-	last_name: string;
-	optional: null | string;
-	pets: null | {
-	age: number;
-	name: string;
-	species: "Cat" | "Dog" | "Monkey" | "Pig";
+	first_name?: string;
+	id?: string;
+	last_name?: string;
+	optional?: null | string;
+	pets?: null | {
+	age?: number;
+	name?: string;
+	species?: "Cat" | "Dog" | "Monkey" | "Pig";
 }[];
 };
 };
